veyron,veyron2: replace Veyron name by Object name everywhere.

Change-Id: I2635a5b19123bffca3743095483b69f1d4e288b0
diff --git a/examples/pipetobrowser/README.md b/examples/pipetobrowser/README.md
index 923fc75..5cf4547 100644
--- a/examples/pipetobrowser/README.md
+++ b/examples/pipetobrowser/README.md
@@ -15,7 +15,7 @@
 cat cat.jpg | p2b -binary google/p2b/jane/image
 ``
 
-where **google/p2b/jane** is the Veyron name where p2b service is running in the browser. The suffix **console** or **image** specifies what viewer should be used to display the data.
+where **google/p2b/jane** is the Object name where p2b service is running in the browser. The suffix **console** or **image** specifies what viewer should be used to display the data.
 
 ## Building and Running
 TODO
@@ -48,7 +48,7 @@
 ### Pipe To Browser
 
 #### Pipe-Viewer
-When a user sends a pipe request to p2b, the suffix of the Veyron name indicates what **viewer** should be used to display the data. For instance:
+When a user sends a pipe request to p2b, the suffix of the Object name indicates what **viewer** should be used to display the data. For instance:
 
 ``
 ls -l | p2b google/p2b/aghassemi/DataTable
diff --git a/examples/pipetobrowser/p2b/main.go b/examples/pipetobrowser/p2b/main.go
index c2f500c..5ecef74 100644
--- a/examples/pipetobrowser/p2b/main.go
+++ b/examples/pipetobrowser/p2b/main.go
@@ -29,7 +29,7 @@
 
 	cat cat.jpg | google/p2b/jane/image
 
-  where <name> (google/p2b/jane) is the veyron name where p2b
+  where <name> (google/p2b/jane) is the object name where p2b
   service is running in the browser. <viewer> (console, image) specifies what
   viewer should be used to display the data.
 
diff --git a/runtimes/google/ipc/benchmarks/bmclient/main.go b/runtimes/google/ipc/benchmarks/bmclient/main.go
index 16c34c5..3afee8c 100644
--- a/runtimes/google/ipc/benchmarks/bmclient/main.go
+++ b/runtimes/google/ipc/benchmarks/bmclient/main.go
@@ -11,7 +11,7 @@
 )
 
 var (
-	server      = flag.String("server", "", "veyron name of the server to connect to")
+	server      = flag.String("server", "", "object name of the server to connect to")
 	count       = flag.Int("count", 1, "number of RPCs to send")
 	chunkCount  = flag.Int("chunk_count", 0, "number of stream chunks to send")
 	payloadSize = flag.Int("payload_size", 32, "the size of the payload")
diff --git a/runtimes/google/ipc/disptrie.go b/runtimes/google/ipc/disptrie.go
index 475db5b..1d5a6a4 100644
--- a/runtimes/google/ipc/disptrie.go
+++ b/runtimes/google/ipc/disptrie.go
@@ -15,7 +15,7 @@
 
 // disptrie represents the dispatch trie, where each trie node holds a slice of
 // dispatchers for that node, and a mapping of children keyed by slash-delimited
-// veyron name fragment.  The trie performs longest-prefix name lookup, and is
+// object name fragment.  The trie performs longest-prefix name lookup, and is
 // safe for concurrent access.
 type disptrie struct {
 	sync.RWMutex
@@ -26,7 +26,7 @@
 	return &disptrie{root: new(trienode)}
 }
 
-// splitName splits the veyron name into its slash-separated components.
+// splitName splits the object name into its slash-separated components.
 func splitName(name string) []string {
 	name = strings.TrimLeft(name, "/")
 	if name == "" {
diff --git a/runtimes/google/rt/mgmt.go b/runtimes/google/rt/mgmt.go
index ccfebd7..d7fae55 100644
--- a/runtimes/google/rt/mgmt.go
+++ b/runtimes/google/rt/mgmt.go
@@ -26,8 +26,8 @@
 	server       ipc.Server // Serves AppCycle service.
 }
 
-// parentName returns the veyron name for the Config service on which we should
-// communicate the veyron name of the app cycle service.  Currently, this can
+// parentName returns the object name for the Config service on which we should
+// communicate the object name of the app cycle service.  Currently, this can
 // be configured either via env vars or via the exec config passed from parent.
 func parentName() (name string) {
 	name = os.Getenv(mgmt.ParentNodeManagerConfigKey)
diff --git a/runtimes/google/security/util.go b/runtimes/google/security/util.go
index 754a5f8..6c9f1aa 100644
--- a/runtimes/google/security/util.go
+++ b/runtimes/google/security/util.go
@@ -88,7 +88,7 @@
 	Method string
 	// Name is the undispatched name for the request.
 	Name string
-	// Suffix is the veyron name suffix for the request.
+	// Suffix is the object name suffix for the request.
 	Suffix string
 	// Label is the security label of the method being invoked.
 	Label security.Label
diff --git a/security/caveat/public_key_caveat.go b/security/caveat/public_key_caveat.go
index 6c5d622..0dcb615 100644
--- a/security/caveat/public_key_caveat.go
+++ b/security/caveat/public_key_caveat.go
@@ -48,7 +48,7 @@
 	// ValidationKey specifies the public key of the discharging-party.
 	ValidationKey wire.PublicKey
 
-	// ThirdPartyLocation specifies the global Veyron name of the discharging-party.
+	// ThirdPartyLocation specifies the global Object name of the discharging-party.
 	ThirdPartyLocation string
 }
 
diff --git a/services/mgmt/application/applicationd/main.go b/services/mgmt/application/applicationd/main.go
index d5e0a33..c42bb7d 100644
--- a/services/mgmt/application/applicationd/main.go
+++ b/services/mgmt/application/applicationd/main.go
@@ -17,7 +17,7 @@
 	flag.StringVar(&address, "address", "localhost:0", "network address to listen on")
 	flag.StringVar(&name, "name", "", "name to mount the application manager as")
 	flag.StringVar(&protocol, "protocol", "tcp", "network type to listen on")
-	flag.StringVar(&storeName, "store", "", "veyron name of the application manager store")
+	flag.StringVar(&storeName, "store", "", "object name of the application manager store")
 	flag.Parse()
 	if storeName == "" {
 		vlog.Fatalf("Specify a store using --store=<name>")
diff --git a/services/mgmt/application/impl/invoker.go b/services/mgmt/application/impl/invoker.go
index 818d053..38e1c28 100644
--- a/services/mgmt/application/impl/invoker.go
+++ b/services/mgmt/application/impl/invoker.go
@@ -18,7 +18,7 @@
 	// metadata.
 	store storage.Store
 	// suffix is the suffix of the current invocation that is assumed to
-	// be used as a relative veyron name to identify an application.
+	// be used as a relative object name to identify an application.
 	suffix string
 }
 
diff --git a/services/mgmt/binary/impl/invoker.go b/services/mgmt/binary/impl/invoker.go
index 84976fa..d28fa03 100644
--- a/services/mgmt/binary/impl/invoker.go
+++ b/services/mgmt/binary/impl/invoker.go
@@ -1,6 +1,6 @@
 // The implementation of the binary repository interface stores
-// objects identified by veyron name suffixes using the local file
-// system. Given a veyron name suffix, the implementation computes an
+// objects identified by object name suffixes using the local file
+// system. Given an object name suffix, the implementation computes an
 // MD5 hash of the suffix and generates the following path in the
 // local filesystem: /<root>/<dir_1>/.../<dir_n>/<hash>. The root and
 // the directory depth are parameters of the implementation. The
@@ -65,13 +65,13 @@
 // invoker holds the state of a binary repository invocation.
 type invoker struct {
 	// path is the local filesystem path to the object identified by the
-	// veyron name suffix.
+	// object name suffix.
 	path string
 	// state holds the state shared across different binary repository
 	// invocations.
 	state *state
 	// suffix is the suffix of the current invocation that is assumed to
-	// be used as a relative veyron name to identify a binary.
+	// be used as a relative object name to identify a binary.
 	suffix string
 }
 
@@ -99,7 +99,7 @@
 // newInvoker is the invoker factory.
 func newInvoker(state *state, suffix string) *invoker {
 	// Generate the local filesystem path for the object identified by
-	// the veyron name suffix.
+	// the object name suffix.
 	h := md5.New()
 	h.Write([]byte(suffix))
 	hash := hex.EncodeToString(h.Sum(nil))
diff --git a/services/mgmt/node/impl/const.go b/services/mgmt/node/impl/const.go
index 5fa0c16..5615eee 100644
--- a/services/mgmt/node/impl/const.go
+++ b/services/mgmt/node/impl/const.go
@@ -6,7 +6,7 @@
 	// the node manager.
 	PreviousEnv = "VEYRON_NM_PREVIOUS"
 	// OriginEnv is the name of the environment variable that holds the
-	// veyron name of the application repository that can be used to
+	// object name of the application repository that can be used to
 	// retrieve the node manager application envelope.
 	OriginEnv = "VEYRON_NM_ORIGIN"
 	// RootEnv is the name of the environment variable that holds the
diff --git a/services/mgmt/node/impl/invoker.go b/services/mgmt/node/impl/invoker.go
index 5a01403..1ddebf0 100644
--- a/services/mgmt/node/impl/invoker.go
+++ b/services/mgmt/node/impl/invoker.go
@@ -89,7 +89,7 @@
 type invoker struct {
 	state *state
 	// suffix is the suffix of the current invocation that is assumed to
-	// be used as a relative veyron name to identify an application,
+	// be used as a relative object name to identify an application,
 	// installation, or instance.
 	suffix string
 }
diff --git a/services/mgmt/node/node.vdl.go b/services/mgmt/node/node.vdl.go
index a131286..0aff95a 100644
--- a/services/mgmt/node/node.vdl.go
+++ b/services/mgmt/node/node.vdl.go
@@ -192,7 +192,7 @@
 // to enable embedding without method collisions.  Not to be used directly by clients.
 type Node_ExcludingUniversal interface {
 	// Node can be used to manage a node. The idea is that this interace
-	// will be invoked using a veyron name that identifies the node.
+	// will be invoked using an object name that identifies the node.
 	node.Node_ExcludingUniversal
 	// Config is an RPC API to the config service.
 	Config_ExcludingUniversal
@@ -206,7 +206,7 @@
 type NodeService interface {
 
 	// Node can be used to manage a node. The idea is that this interace
-	// will be invoked using a veyron name that identifies the node.
+	// will be invoked using an object name that identifies the node.
 	node.NodeService
 	// Config is an RPC API to the config service.
 	ConfigService
diff --git a/services/mgmt/profile/impl/invoker.go b/services/mgmt/profile/impl/invoker.go
index bb7ad12..aa95dcb 100644
--- a/services/mgmt/profile/impl/invoker.go
+++ b/services/mgmt/profile/impl/invoker.go
@@ -17,7 +17,7 @@
 	// store is the storage server used for storing profile data.
 	store storage.Store
 	// suffix is the suffix of the current invocation that is assumed to
-	// be used as a relative veyron name to identify a profile
+	// be used as a relative object name to identify a profile
 	// specification.
 	suffix string
 }
diff --git a/services/mgmt/profile/profiled/main.go b/services/mgmt/profile/profiled/main.go
index cc33f62..c4ab605 100644
--- a/services/mgmt/profile/profiled/main.go
+++ b/services/mgmt/profile/profiled/main.go
@@ -17,7 +17,7 @@
 	flag.StringVar(&address, "address", "localhost:0", "network address to listen on")
 	flag.StringVar(&name, "name", "", "name to mount the profile manager as")
 	flag.StringVar(&protocol, "protocol", "tcp", "network type to listen on")
-	flag.StringVar(&storeName, "store", "", "veyron name of the profile manager store")
+	flag.StringVar(&storeName, "store", "", "object name of the profile manager store")
 	flag.Parse()
 	if storeName == "" {
 		vlog.Fatalf("Specify a store using --store=<name>")
diff --git a/services/mgmt/repository/repository.vdl b/services/mgmt/repository/repository.vdl
index 5ef30d9..bbdb35d 100644
--- a/services/mgmt/repository/repository.vdl
+++ b/services/mgmt/repository/repository.vdl
@@ -15,11 +15,11 @@
 type Application interface {
 	public.Application
 	// Put adds the given tuple of application version (specified
-	// through the veyron name suffix) and application envelope to all
+	// through the object name suffix) and application envelope to all
 	// of the given application profiles.
 	Put(Profiles []string, Envelope application.Envelope) error {security.WriteLabel}
 	// Remove removes the application envelope for the given profile
-	// name and application version (specified through the veyron name
+	// name and application version (specified through the object name
 	// suffix). If no version is specified as part of the suffix, the
 	// method removes all versions for the given profile.
 	//
@@ -33,12 +33,12 @@
 type Profile interface {
 	public.Profile
 	// Specification returns the profile specification for the profile
-	// identified through the veyron name suffix.
+	// identified through the object name suffix.
 	Specification() (profile.Specification, error) {security.ReadLabel}
 	// Put sets the profile specification for the profile identified
-	// through the veyron name suffix.
+	// through the object name suffix.
 	Put(Specification profile.Specification) error {security.WriteLabel}
 	// Remove removes the profile specification for the profile
-	// identified through the veyron name suffix.
+	// identified through the object name suffix.
 	Remove() error {security.WriteLabel}
 }
diff --git a/services/mgmt/repository/repository.vdl.go b/services/mgmt/repository/repository.vdl.go
index 10a9336..683d069 100644
--- a/services/mgmt/repository/repository.vdl.go
+++ b/services/mgmt/repository/repository.vdl.go
@@ -33,7 +33,7 @@
 type Application_ExcludingUniversal interface {
 	// Application provides access to application envelopes. An
 	// application envelope is identified by an application name and an
-	// application version, which are specified through the veyron name,
+	// application version, which are specified through the object name,
 	// and a profile name, which is specified using a method argument.
 	//
 	// Example:
@@ -43,11 +43,11 @@
 	//   on either the "base" or "media" profile.
 	repository.Application_ExcludingUniversal
 	// Put adds the given tuple of application version (specified
-	// through the veyron name suffix) and application envelope to all
+	// through the object name suffix) and application envelope to all
 	// of the given application profiles.
 	Put(ctx _gen_context.T, Profiles []string, Envelope application.Envelope, opts ..._gen_ipc.CallOpt) (err error)
 	// Remove removes the application envelope for the given profile
-	// name and application version (specified through the veyron name
+	// name and application version (specified through the object name
 	// suffix). If no version is specified as part of the suffix, the
 	// method removes all versions for the given profile.
 	//
@@ -65,7 +65,7 @@
 
 	// Application provides access to application envelopes. An
 	// application envelope is identified by an application name and an
-	// application version, which are specified through the veyron name,
+	// application version, which are specified through the object name,
 	// and a profile name, which is specified using a method argument.
 	//
 	// Example:
@@ -75,11 +75,11 @@
 	//   on either the "base" or "media" profile.
 	repository.ApplicationService
 	// Put adds the given tuple of application version (specified
-	// through the veyron name suffix) and application envelope to all
+	// through the object name suffix) and application envelope to all
 	// of the given application profiles.
 	Put(context _gen_ipc.ServerContext, Profiles []string, Envelope application.Envelope) (err error)
 	// Remove removes the application envelope for the given profile
-	// name and application version (specified through the veyron name
+	// name and application version (specified through the object name
 	// suffix). If no version is specified as part of the suffix, the
 	// method removes all versions for the given profile.
 	//
@@ -344,13 +344,13 @@
 	// devices, and are used to match them.
 	repository.Profile_ExcludingUniversal
 	// Specification returns the profile specification for the profile
-	// identified through the veyron name suffix.
+	// identified through the object name suffix.
 	Specification(ctx _gen_context.T, opts ..._gen_ipc.CallOpt) (reply profile.Specification, err error)
 	// Put sets the profile specification for the profile identified
-	// through the veyron name suffix.
+	// through the object name suffix.
 	Put(ctx _gen_context.T, Specification profile.Specification, opts ..._gen_ipc.CallOpt) (err error)
 	// Remove removes the profile specification for the profile
-	// identified through the veyron name suffix.
+	// identified through the object name suffix.
 	Remove(ctx _gen_context.T, opts ..._gen_ipc.CallOpt) (err error)
 }
 type Profile interface {
@@ -367,13 +367,13 @@
 	// devices, and are used to match them.
 	repository.ProfileService
 	// Specification returns the profile specification for the profile
-	// identified through the veyron name suffix.
+	// identified through the object name suffix.
 	Specification(context _gen_ipc.ServerContext) (reply profile.Specification, err error)
 	// Put sets the profile specification for the profile identified
-	// through the veyron name suffix.
+	// through the object name suffix.
 	Put(context _gen_ipc.ServerContext, Specification profile.Specification) (err error)
 	// Remove removes the profile specification for the profile
-	// identified through the veyron name suffix.
+	// identified through the object name suffix.
 	Remove(context _gen_ipc.ServerContext) (err error)
 }
 
diff --git a/services/store/memstore/blackbox/photoalbum_test.go b/services/store/memstore/blackbox/photoalbum_test.go
index 9890fe3..ad9e487 100644
--- a/services/store/memstore/blackbox/photoalbum_test.go
+++ b/services/store/memstore/blackbox/photoalbum_test.go
@@ -29,12 +29,12 @@
 	SSN int
 }
 
-// Photo represents an image.  It contains the Veyron name for the data,
+// Photo represents an image.  It contains the Object name for the data,
 // stored elsewhere on some content server.
 type Photo struct {
 	Dir
 	Comment string
-	Content string // Veyron name
+	Content string // Object name
 	Edits   []Edit
 }
 
diff --git a/services/store/memstore/query/eval.go b/services/store/memstore/query/eval.go
index d8a78d8..10a490d 100644
--- a/services/store/memstore/query/eval.go
+++ b/services/store/memstore/query/eval.go
@@ -296,7 +296,7 @@
 	//   { Name: "teams/cardinals", Fields: {"numplayers": [{Name: "numplayers", Value: 5}]}}
 	singleResult() bool
 
-	// name returns a relative Veyron name that is appropriate for the query
+	// name returns a relative Object name that is appropriate for the query
 	// results produced by this evaluator.
 	name() string
 }
@@ -1000,9 +1000,9 @@
 	return e.i
 }
 
-// exprName is an expr for a Veyron name literal.
+// exprName is an expr for an Object name literal.
 type exprName struct {
-	// name is the Veyron name used in the query.
+	// name is the Object name used in the query.
 	name string
 	// pos specifies where in the query string this component started.
 	pos parse.Pos
diff --git a/services/store/memstore/query/eval_test.go b/services/store/memstore/query/eval_test.go
index 8dd7e81..148ace0 100644
--- a/services/store/memstore/query/eval_test.go
+++ b/services/store/memstore/query/eval_test.go
@@ -118,7 +118,7 @@
 		{"", "teams | ?2 > 1.7", []string{"teams"}},
 		{"", "teams | ?2.3 > 1", []string{"teams"}},
 		{"", "teams | ?-2 > 1.7", []string{}},
-		// Veyron names:
+		// Object names:
 		{"", "teams/* | type team | ?Name > 'bar'", []string{"teams/cardinals", "teams/sharks", "teams/bears"}},
 		{"", "teams/* | type team | ?Name > 'foo'", []string{"teams/sharks"}},
 		{"", "teams/* | type team | ?Name != 'bears'", []string{"teams/cardinals", "teams/sharks"}},
diff --git a/services/store/raw/service.vdl b/services/store/raw/service.vdl
index 6bf5b19..de0d6b4 100644
--- a/services/store/raw/service.vdl
+++ b/services/store/raw/service.vdl
@@ -10,8 +10,8 @@
 )
 
 const (
-  // The raw Store has Veyron name "<mount>/.store.raw", where <mount> is the
-  // Veyron name of the mount point.
+  // The raw Store has Object name "<mount>/.store.raw", where <mount> is the
+  // Object name of the mount point.
   RawStoreSuffix = ".store.raw"
 )
 
diff --git a/services/store/raw/service.vdl.go b/services/store/raw/service.vdl.go
index f1228b0..9e532c0 100644
--- a/services/store/raw/service.vdl.go
+++ b/services/store/raw/service.vdl.go
@@ -54,8 +54,8 @@
 }
 
 const (
-	// The raw Store has Veyron name "<mount>/.store.raw", where <mount> is the
-	// Veyron name of the mount point.
+	// The raw Store has Object name "<mount>/.store.raw", where <mount> is the
+	// Object name of the mount point.
 	RawStoreSuffix = ".store.raw"
 )
 
diff --git a/services/store/stored/main.go b/services/store/stored/main.go
index 1d820b1..0988933 100644
--- a/services/store/stored/main.go
+++ b/services/store/stored/main.go
@@ -7,8 +7,8 @@
 //     - <name> is the Veyron mount point name, default /global/vstore/<hostname>/<username>.
 //     - <dbName> is the filename in which to store the data.
 //
-// The store service has Veyron name, <name>/.store.
-// The raw store service has Veyron name, <name>/.store.raw.
+// The store service has Object name, <name>/.store.
+// The raw store service has Object name, <name>/.store.raw.
 // Individual values with path <path> have name <name>/<path>.
 package main
 
diff --git a/services/store/testutil/store.go b/services/store/testutil/store.go
index a53fd88..50feb22 100644
--- a/services/store/testutil/store.go
+++ b/services/store/testutil/store.go
@@ -14,7 +14,7 @@
 )
 
 // NewStore creates a new testing instance of the store server and returns
-// a veyron name that identifies the instance and a closure that can
+// an object name that identifies the instance and a closure that can
 // be used to terminate the instance and clean up.
 func NewStore(t *testing.T, server ipc.Server, id security.PublicID) (string, func()) {
 	// Create a temporary directory for the store server.
diff --git a/services/wspr/wsprd/lib/wspr.go b/services/wspr/wsprd/lib/wspr.go
index 4251ed9..4c76bd0 100644
--- a/services/wspr/wsprd/lib/wspr.go
+++ b/services/wspr/wsprd/lib/wspr.go
@@ -87,7 +87,7 @@
 	// Making a veyron client request, streaming or otherwise
 	websocketVeyronRequest websocketMessageType = 0
 
-	// Publishing this websocket under a veyron name
+	// Publishing this websocket under an object name
 	websocketPublishServer = 1
 
 	// A response from a service in javascript to a request
diff --git a/tools/binary/impl/impl.go b/tools/binary/impl/impl.go
index 9075b72..d4d205f 100644
--- a/tools/binary/impl/impl.go
+++ b/tools/binary/impl/impl.go
@@ -17,7 +17,7 @@
 	Short:    "Delete binary",
 	Long:     "Delete connects to the binary repository and deletes the specified binary",
 	ArgsName: "<binary>",
-	ArgsLong: "<binary> is the veyron name of the binary to delete",
+	ArgsLong: "<binary> is the object name of the binary to delete",
 }
 
 func runDelete(cmd *cmdline.Command, args []string) error {
@@ -47,7 +47,7 @@
 `,
 	ArgsName: "<binary> <filename>",
 	ArgsLong: `
-<binary> is the veyron name of the binary to download
+<binary> is the object name of the binary to download
 <filename> is the name of the file where the binary will be written
 `,
 }
@@ -108,7 +108,7 @@
 `,
 	ArgsName: "<binary> <filename>",
 	ArgsLong: `
-<binary> is the veyron name of the binary to upload
+<binary> is the object name of the binary to upload
 <filename> is the name of the file to upload
 `,
 }
diff --git a/tools/mounttable/impl/impl.go b/tools/mounttable/impl/impl.go
index 0446a66..6986e4f 100644
--- a/tools/mounttable/impl/impl.go
+++ b/tools/mounttable/impl/impl.go
@@ -78,7 +78,7 @@
 	ArgsName: "<mount name> <name> <ttl>",
 	ArgsLong: `
 <mount name> is a mount name on a mount table.
-<name> is the rooted veyron name of the server.
+<name> is the rooted object name of the server.
 <ttl> is the TTL of the new entry. It is a decimal number followed by a unit
 suffix (s, m, h). A value of 0s represents an infinite duration.
 `,
@@ -113,7 +113,7 @@
 	ArgsName: "<mount name> <name>",
 	ArgsLong: `
 <mount name> is a mount name on a mount table.
-<name> is the rooted veyron name of the server.
+<name> is the rooted object name of the server.
 `,
 }
 
diff --git a/tools/proximity/impl/impl.go b/tools/proximity/impl/impl.go
index a7e6ed6..907436a 100644
--- a/tools/proximity/impl/impl.go
+++ b/tools/proximity/impl/impl.go
@@ -16,7 +16,7 @@
 	Long:     "register adds a name that the remote device will be associated with.",
 	ArgsName: "<address> <name>",
 	ArgsLong: `
-<address> is the veyron name of the proximity server.
+<address> is the object name of the proximity server.
 <name> is the name to register.
 `,
 }
@@ -43,7 +43,7 @@
 	Long:     "unregister removes a name that the remote device it is associated with.",
 	ArgsName: "<address> <name>",
 	ArgsLong: `
-<address> is the veyron name of the proximity server.
+<address> is the object name of the proximity server.
 <name> is the name to unregister.
 `,
 }
@@ -69,7 +69,7 @@
 	Short:    "nearbydevices displayes the most up-to-date list of nearby devices.",
 	Long:     "nearbydevices displayes the most up-to-date list of nearby devices.",
 	ArgsName: "<address>",
-	ArgsLong: "<address> is the veyron name of the proximity server.",
+	ArgsLong: "<address> is the object name of the proximity server.",
 }
 
 func runNearbyDevices(cmd *cmdline.Command, args []string) error {
diff --git a/tools/vrpc/impl/impl.go b/tools/vrpc/impl/impl.go
index 05579b7..27ce11e 100644
--- a/tools/vrpc/impl/impl.go
+++ b/tools/vrpc/impl/impl.go
@@ -23,7 +23,7 @@
 
 const serverDesc = `
 <server> identifies the Veyron RPC server. It can either be the object address of
-the server or a Veyron name in which case the vrpc will use Veyron's name
+the server or an Object name in which case the vrpc will use Veyron's name
 resolution to match this name to an end-point.
 `
 const methodDesc = `
diff --git a/examples/tunnel/vsh/main.go b/examples/tunnel/vsh/main.go
index 42165b4..8917472 100644
--- a/examples/tunnel/vsh/main.go
+++ b/examples/tunnel/vsh/main.go
@@ -21,7 +21,7 @@
 var (
 	disablePty = flag.Bool("T", false, "Disable pseudo-terminal allocation.")
 	forcePty   = flag.Bool("t", false, "Force allocation of pseudo-terminal.")
-	vname      = flag.String("vname", "", "Veyron name (or endpoint) for tunneling service.")
+	oname      = flag.String("oname", "", "Object name (or endpoint) for tunneling service.")
 
 	portforward = flag.String("L", "", "localaddr,remoteaddr Forward local 'localaddr' to 'remoteaddr'")
 	lprotocol   = flag.String("local_protocol", "tcp", "Local network protocol for port forwarding")
@@ -39,10 +39,10 @@
 tunneld service.
 
 To open an interactive shell, use:
-  %s --host=<veyron name or endpoint>
+  %s --host=<object name or endpoint>
 
 To run a shell command, use:
   %s --host=<veyron name or endpoint> <command to run>
 
 The -L flag will forward connections from a local port to a remote address
 through the tunneld service. The flag value is localaddr,remoteaddr. E.g.
@@ -145,12 +145,12 @@
 	return env
 }
 
 // veyronNameAndCommandLine extracts the veyron name and the remote command to
 // send to the server. The name can be specified with the --vname flag or as the
 // first non-flag argument. The command line is the concatenation of all the
 // non-flag arguments, minus the veyron name.
 func veyronNameAndCommandLine() (string, string, error) {
-	name := *vname
+	name := *oname
 	args := flag.Args()
 	if len(name) == 0 {
 		if len(args) > 0 {
@@ -159,7 +159,7 @@
 		}
 	}
 	if len(name) == 0 {
-		return "", "", errors.New("veyron name missing")
+		return "", "", errors.New("object name missing")
 	}
 	// For compatibility with tools like rsync. Because veyron addresses
 	// don't look like traditional hostnames, tools that work with rsh and
@@ -39,10 +39,10 @@
 
 To run a shell command, use:
-  %s --host=<veyron name or endpoint> <command to run>
+  %s --host=<object name or endpoint> <command to run>
 
 The -L flag will forward connections from a local port to a remote address
@@ -145,12 +145,12 @@
 }
 
-// veyronNameAndCommandLine extracts the veyron name and the remote command to
-// send to the server. The name can be specified with the --vname flag or as the
+// veyronNameAndCommandLine extracts the object name and the remote command to
+// send to the server. The name can be specified with the --oname flag or as the
 // first non-flag argument. The command line is the concatenation of all the
@@ -145,12 +145,12 @@
 // first non-flag argument. The command line is the concatenation of all the
-// non-flag arguments, minus the veyron name.
+// non-flag arguments, minus the object name.
 func veyronNameAndCommandLine() (string, string, error) {